@@ -8,7 +8,7 @@
  */
 
 #include "gmenu.h"
-
+#include <libgnomeui/gnome-window-icon.h>
 /*
  *-----------------------------------------------------------------------------
  * global variables (public)
@@ -274,6 +274,7 @@ int main (int argc, char *argv[])
 	textdomain(PACKAGE);
 
 	gnome_init ("GNOME menu editor", VERSION, argc, argv);
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-gmenu.png");
 
 	system_apps_dir = gnome_datadir_file("gnome/apps");
 	system_applets_dir = gnome_datadir_file("applets");
@@ -326,7 +327,6 @@ int main (int argc, char *argv[])
 	
 	gtk_clist_set_row_height(GTK_CLIST(tree),22);
 	gtk_ctree_set_indent (GTK_CTREE (tree), 10);
-        gtk_ctree_set_line_style (GTK_CTREE (tree), GTK_CTREE_LINES_DOTTED);
 
 	gtk_clist_set_selection_mode(GTK_CLIST(tree),
 				     GTK_SELECTION_BROWSE);
