@@ -227,7 +227,7 @@ auth_proc (char* hostname)
  * to the world.  It loops from -1 to -256, as the socket might be in use
  */
 static gboolean
-init_well_known_connections (void)
+init_ice_connections (void)
 {
 	char error [256];
 	char buffer [32];
@@ -271,19 +271,14 @@ initialize_ice (void)
   if (SmsInitialize (GsmVendor, VERSION, new_client, NULL,
 		     auth_proc, sizeof error, error)) 
     {
-#warning FIXME: we really do not want to allow TCP connections by default
-#if 0
-      if (allow_tcp)
-	{
+      if (!allow_tcp){
+#ifdef HAVE__ICETRANSNOLISTEN
+	_IceTransNoListen ("tcp");
 #endif
-	  if (IceListenForConnections (&num_sockets, &sockets,
-				       sizeof(error), error))
-	    init_error = FALSE;
-#if 0
-	}
-      else if (init_well_known_connections ())
+      }
+      if (IceListenForConnections (&num_sockets, &sockets,
+				   sizeof(error), error))
 	init_error = FALSE;
-#endif
     }
 
   if (init_error)
