@@ -24,8 +24,9 @@
 #include <signal.h>
 #include <stdlib.h>
 
-#include "libgnome/libgnome.h"
-#include "libgnomeui/libgnomeui.h"
+#include <libgnome/libgnome.h>
+#include <libgnomeui/libgnomeui.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include "manager.h"
 #include "session.h"
 #include "splash.h"
@@ -106,6 +107,7 @@ main (int argc, char *argv[])
   gnome_client_disable_master_connection ();
   gnome_init_with_popt_table("gnome-session", VERSION, argc, argv, options, 0,
 			     &ctx);
+  gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-session.png");
   leftovers = poptGetArgs(ctx);
   if(leftovers && leftovers[0]) 
     session = leftovers[0];
