@@ -60,7 +60,9 @@ panel_clean_applet(AppletInfo *info)
 		if(info->type == APPLET_STATUS) {
 			status_applet_put_offscreen(info->data);
 		}
+		/* destroy will remove it from the panel */
 		gtk_widget_destroy(info->widget);
+		info->widget = NULL;
 	}
 }
 
@@ -240,8 +242,8 @@ applet_add_callback(AppletInfo *info,
 			menu->menuitem=NULL;
 			menu->submenu=NULL;
 		}
-		gtk_widget_destroy(info->menu);
-		info->menu=NULL;
+		gtk_widget_unref(info->menu);
+		info->menu = NULL;
 		info->menu_age = 0;
 	}
 }
@@ -273,8 +275,8 @@ applet_remove_callback(AppletInfo *info, const char *callback_name)
 			menu->menuitem=NULL;
 			menu->submenu=NULL;
 		}
-		gtk_widget_destroy(info->menu);
-		info->menu=NULL;
+		gtk_widget_unref(info->menu);
+		info->menu = NULL;
 		info->menu_age = 0;
 	}
 }
@@ -299,8 +301,8 @@ applet_callback_set_sensitive(AppletInfo *info, const char *callback_name, int s
 			menu->menuitem=NULL;
 			menu->submenu=NULL;
 		}
-		gtk_widget_destroy(info->menu);
-		info->menu=NULL;
+		gtk_widget_unref(info->menu);
+		info->menu = NULL;
 		info->menu_age = 0;
 	}
 }
@@ -449,7 +451,7 @@ create_applet_menu(AppletInfo *info, gboolean is_basep)
 
 	pixmap = gnome_pixmap_file ("gnome-panel.png");
 	if (!pixmap) {
-		g_warning (_("Cannot find pixmap file %s"), "gnome-panel.png");
+		g_message (_("Cannot find pixmap file %s"), "gnome-panel.png");
 		setup_menuitem (menuitem, NULL, _("Panel"));
 	} else {
 		setup_menuitem (menuitem, 
@@ -565,7 +567,7 @@ applet_destroy(GtkWidget *w, AppletInfo *info)
 		}
 	}
 	if(info->menu) {
-		gtk_widget_destroy(info->menu);
+		gtk_widget_unref(info->menu);
 		info->menu = NULL;
 		info->menu_age = 0;
 	}
@@ -622,8 +624,10 @@ register_toy(GtkWidget *applet,
 	 * sink the object.
 	 */
 
+	/*
 	gtk_widget_ref (info->widget);
 	gtk_object_sink (GTK_OBJECT (info->widget));
+	*/
 
 	gtk_object_set_data(GTK_OBJECT(applet),"applet_info",info);
 
