@@ -1,5 +1,6 @@
 /* Gnome panel: extern applet functions
- * (C) 1997 the Free Software Foundation
+ * (C) 1997,1998,1999,2000 the Free Software Foundation
+ * (C) 2000 Eazel, Inc.
  *
  * Authors:  George Lebl
  *           Federico Mena
@@ -297,6 +298,10 @@ extern_clean(Extern *ext)
 		gtk_timeout_remove(ext->send_draw_timeout);
 		ext->send_draw_timeout = 0;
 	}
+	if(ext->send_draw_idle) {
+		gtk_idle_remove(ext->send_draw_idle);
+		ext->send_draw_idle = 0;
+	}
 
 	g_free(ext);
 
@@ -472,6 +477,7 @@ load_extern_applet(char *goad_id, char *cfgpath, PanelWidget *panel,
 	ext->orient = -1;
 
 	ext->send_draw_timeout = 0;
+	ext->send_draw_idle = 0;
 	ext->send_draw_queued = FALSE;
 
 
@@ -904,6 +910,7 @@ s_panelspot_get_rgb_background(PortableServer_Servant servant,
 		memcpy(image->data._buffer,rgb,sizeof(guchar)*h*rowstride);
 		image->rowstride = rowstride;
 		image->color_only = FALSE;
+		g_free(rgb);
 	} else { /* we must have gotten a color */
 		image->data._buffer = CORBA_sequence_CORBA_octet_allocbuf(3);
 		image->data._length = image->data._maximum = 3;
@@ -1300,11 +1307,11 @@ send_draw(Extern *ext)
 	CORBA_exception_free(&ev);
 }
 
-static int
+static gboolean
 send_draw_timeout(gpointer data)
 {
 	Extern *ext = data;
-	if(ext->send_draw_queued == TRUE) {
+	if(ext->send_draw && ext->send_draw_queued) {
 		ext->send_draw_queued = FALSE;
 		send_draw(ext);
 		return TRUE;
@@ -1313,16 +1320,29 @@ send_draw_timeout(gpointer data)
 	return FALSE;
 }
 
+static gboolean
+send_draw_idle(gpointer data)
+{
+	Extern *ext = data;
+	ext->send_draw_idle = 0;
+	if(!ext->send_draw)
+		return FALSE;
+	if(!ext->send_draw_timeout) {
+		ext->send_draw_queued = FALSE;
+		send_draw(ext);
+		ext->send_draw_timeout =
+			gtk_timeout_add(1000, send_draw_timeout, ext);
+	} else 
+		ext->send_draw_queued = TRUE;
+	return FALSE;
+}
+
 void
 extern_send_draw(Extern *ext)
 {
 	if(!ext || !ext->applet || !ext->send_draw)
 		return;
-	if(!ext->send_draw_timeout) {
-		ext->send_draw_queued = FALSE;
-		send_draw(ext);
-		ext->send_draw_timeout =
-			gtk_timeout_add(1000,send_draw_timeout,ext);
-	} else 
-		ext->send_draw_queued = TRUE;
+	if(!ext->send_draw_idle)
+		ext->send_draw_idle =
+			gtk_idle_add(send_draw_idle, ext);
 }
