@@ -1432,8 +1432,7 @@ panel_widget_set_back_pixmap (PanelWidget *panel, char *file)
 #endif
 
 	if (panel_try_to_set_pixmap (panel, file)) {
-		if (panel->back_pixmap)
-			g_free (panel->back_pixmap);
+		g_free (panel->back_pixmap);
 		panel->back_pixmap = g_strdup (file);
 		panel->back_type = PANEL_BACK_PIXMAP;
 		panel_widget_draw_all(panel,NULL);
@@ -1653,15 +1652,20 @@ panel_widget_realize(GtkWidget *w, gpointer data)
 static void
 panel_widget_destroy(GtkWidget *w, gpointer data)
 {
-	PanelWidget *panel = PANEL_WIDGET(w);
+	PanelWidget *panel;
 
 	g_return_if_fail(w!=NULL);
 	g_return_if_fail(IS_PANEL_WIDGET(w));
 
+	panel = PANEL_WIDGET(w);
+
 	if(panel->backpix)
 		gdk_pixbuf_unref(panel->backpix);
 	panel->backpix = NULL;
-	
+
+	g_free (panel->back_pixmap);
+	panel->back_pixmap = NULL;
+
 	/*remove from panels list*/
 	panels = g_slist_remove(panels,w);
 }
@@ -2759,9 +2763,8 @@ panel_widget_change_params(PanelWidget *panel,
 	if(pixmap && pixmap != panel->back_pixmap) {
 		if(back_type == PANEL_BACK_PIXMAP)
 			change_back = TRUE;
-		if (panel->back_pixmap)
-			g_free (panel->back_pixmap);
 
+		g_free (panel->back_pixmap);
 		panel->back_pixmap = g_strdup (pixmap);
 	}
 
